@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 
-from datetime import date
 from imio.smartweb.core.config import EVENTS_URL
 from imio.smartweb.core.contents.rest.base import BaseEndpoint
 from imio.smartweb.core.contents.rest.base import BaseService
@@ -14,7 +13,7 @@ from zope.interface import Interface
 class BaseEventsEndpoint(BaseEndpoint):
     def __call__(self):
         results = super(BaseEventsEndpoint, self).__call__()
-        if not results.get("items"):
+        if not results or not results.get("items"):
             return results
         orientation = self.context.orientation
         for result in results["items"]:
@@ -33,17 +32,16 @@ class BaseEventsEndpoint(BaseEndpoint):
 
     @property
     def query_url(self):
-        today = date.today().isoformat()
         params = [
             "selected_agendas={}".format(self.context.selected_agenda),
             "metadata_fields=category",
+            "metadata_fields=local_category",
+            "metadata_fields=container_uid",
             "metadata_fields=topics",
             "metadata_fields=start",
             "metadata_fields=end",
             "metadata_fields=has_leadimage",
             "metadata_fields=UID",
-            "event_dates.query={}".format(today),
-            "event_dates.range=min",
             "sort_on=event_dates",
             "fullobjects=1",
             "b_size={}".format(self.context.nb_results),
