@@ -150,7 +150,10 @@ class SectionsFunctionalTest(ImioSmartwebTestCase):
         )
 
         request = TestRequest(
-            form={"topics": "education", "metadata_fields": ["topics", "category"]}
+            form={
+                "topics": "education",
+                "metadata_fields": ["topics", "category"],
+            }
         )
         endpoint = DirectoryEndpoint(self.portal, request)
         params = endpoint.get_extra_params([])
@@ -369,13 +372,13 @@ class SectionsFunctionalTest(ImioSmartwebTestCase):
             "http://localhost:8080/Plone/@events?"
             "selected_agendas={}&"
             "metadata_fields=category&"
+            "metadata_fields=local_category&"
+            "metadata_fields=container_uid&"
             "metadata_fields=topics&"
             "metadata_fields=start&"
             "metadata_fields=end&"
             "metadata_fields=has_leadimage&"
             "metadata_fields=UID&"
-            "event_dates.query=2021-11-15&"
-            "event_dates.range=min&"
             "sort_on=event_dates&"
             "fullobjects=1&"
             "b_size=20&"
@@ -427,6 +430,8 @@ class SectionsFunctionalTest(ImioSmartwebTestCase):
             "selected_news_folders={}&"
             "portal_type=imio.news.NewsItem&"
             "metadata_fields=category&"
+            "metadata_fields=local_category&"
+            "metadata_fields=container_uid&"
             "metadata_fields=topics&"
             "metadata_fields=has_leadimage&"
             "metadata_fields=UID&"
@@ -489,6 +494,40 @@ class SectionsFunctionalTest(ImioSmartwebTestCase):
         view = queryMultiAdapter((self.rest_events, self.request), name="view")
         self.assertIn('display-map="True"', view())
 
+    def test_show_categories_or_topics(self):
+        rest_events = api.content.create(
+            container=self.portal,
+            type="imio.smartweb.EventsView",
+            title="events view",
+        )
+        view = queryMultiAdapter((rest_events, self.request), name="view")
+        self.assertIn('show-categories-or-topics="category"', view())
+        rest_events.show_categories_or_topics = "category"
+        view = queryMultiAdapter((rest_events, self.request), name="view")
+        self.assertIn('show-categories-or-topics="category"', view())
+        rest_events.show_categories_or_topics = "topic"
+        view = queryMultiAdapter((rest_events, self.request), name="view")
+        self.assertIn('show-categories-or-topics="topic"', view())
+        rest_events.show_categories_or_topics = ""
+        view = queryMultiAdapter((rest_events, self.request), name="view")
+        self.assertIn('show-categories-or-topics=""', view())
+        rest_news = api.content.create(
+            container=self.portal,
+            type="imio.smartweb.NewsView",
+            title="news view",
+        )
+        view = queryMultiAdapter((rest_news, self.request), name="view")
+        self.assertIn('show-categories-or-topics="category"', view())
+        rest_news.show_categories_or_topics = "category"
+        view = queryMultiAdapter((rest_news, self.request), name="view")
+        self.assertIn('show-categories-or-topics="category"', view())
+        rest_news.show_categories_or_topics = "topic"
+        view = queryMultiAdapter((rest_news, self.request), name="view")
+        self.assertIn('show-categories-or-topics="topic"', view())
+        rest_news.show_categories_or_topics = ""
+        view = queryMultiAdapter((rest_news, self.request), name="view")
+        self.assertIn('show-categories-or-topics=""', view())
+
     @patch("imio.smartweb.core.rest.authentic_sources.get_wca_token")
     @patch("imio.smartweb.core.rest.authentic_sources.requests.request")
     @patch("imio.smartweb.core.rest.authentic_sources.get_default_view_url")
