@@ -118,6 +118,23 @@ class CurrentFolderPagesVocabularyFactory:
 CurrentFolderPagesVocabulary = CurrentFolderPagesVocabularyFactory()
 
 
+class CategoriesDisplayVocabularyFactory:
+    def __call__(self, context=None):
+        values = [
+            ("category", _("Category")),
+            ("topic", _("Topic")),
+            ("", _("None")),
+        ]
+        terms = [
+            SimpleVocabulary.createTerm(value[0], value[0], value[1])
+            for value in values
+        ]
+        return SimpleVocabulary(terms)
+
+
+CategoriesDisplayVocabulary = CategoriesDisplayVocabularyFactory()
+
+
 class BootstrapCSSVocabularyFactory:
     def __call__(self, context=None):
         bootstrap_css = [
@@ -505,7 +522,7 @@ class EventsFromEntityVocabularyFactory:
         params = [
             selected_agendas,
             "portal_type=imio.events.Event",
-            "metadata_fields=category",
+            "metadata_fields=category_title",
             "metadata_fields=topics",
             "metadata_fields=start",
             "metadata_fields=end",
@@ -545,7 +562,7 @@ class NewsItemsFromEntityVocabularyFactory:
         params = [
             selected_newsfolders,
             "portal_type=imio.news.NewsItem",
-            "metadata_fields=category",
+            "metadata_fields=category_title",
             "metadata_fields=topics",
             "metadata_fields=has_leadimage",
             "metadata_fields=breadcrumb",
