@@ -1,18 +1,20 @@
 import React, { useEffect, useState, useRef } from "react";
-import { BrowserRouter as Router, Switch, Route } from "react-router-dom";
+import { BrowserRouter, Routes, Route } from "react-router-dom";
 import Filters from "./Filters/Filter";
 import ContactContent from "./ContactContent/ContactContent";
 import ContactList from "./ContactList/ContactList";
 import Map from "../../utils/Map";
 import useAxios from "../../hooks/useAxios";
 import "./Annuaire.scss";
+import "../Filters/MainFilter.scss";
 import useFilterQuery from "../../hooks/useFilterQuery";
 import { Provider, Translate } from "react-translated";
-import translation from '../../utils/translation';
+import translation from "../../utils/translation";
+import queryString from "query-string";
 
 export default function Annuaire(props) {
     return (
-        <Router basename={props.viewPath}>
+        <BrowserRouter basename={props.viewPath}>
             <Provider language={props.currentLanguage} translation={translation}>
                 <AnnuaireView
                     queryFilterUrl={props.queryFilterUrl}
@@ -22,11 +24,10 @@ export default function Annuaire(props) {
                     displayMap={props.displayMap}
                 />
             </Provider>
-        </Router>
+        </BrowserRouter>
     );
 }
 function AnnuaireView(props) {
-    const queryString = require("query-string");
     const { u, ...parsed } = Object.assign(
         { b_start: 0, fullobjects: 1 },
         queryString.parse(useFilterQuery().toString())
@@ -100,15 +101,15 @@ function AnnuaireView(props) {
     }, [batchStart]);
 
     // filter top style
-    let portalHeader = document.getElementById("portal-header");
-    let portalHeaderHeight = portalHeader.offsetHeight;
-
     const filterRef = useRef();
     const [style, setStyle] = React.useState({ height: 0 });
+    const [headerHeight, setHeaderHeight] = useState(0);
+
     useEffect(() => {
         setStyle({
             height: filterRef.current.clientHeight,
         });
+        setHeaderHeight(filterRef.current.offsetTop);
     }, [filterRef.current]);
 
     // coditional list render
@@ -120,7 +121,7 @@ function AnnuaireView(props) {
         );
         MapRender = (
             <Map
-                headerHeight={style.height + portalHeaderHeight}
+                headerHeight={style.height + headerHeight}
                 clickId={clickId}
                 hoverId={hoverId}
                 items={contactArray}
@@ -128,16 +129,33 @@ function AnnuaireView(props) {
             />
         );
     } else if (!isLoading) {
-        listRender = <p><Translate text="Aucun contact n'a été trouvé" /></p>;
+        listRender = (
+            <p>
+                <Translate text="Aucun contact n'a été trouvé" />
+            </p>
+        );
     }
 
-    const divLoader = <div className="lds-roller-container"><div className="lds-roller"><div></div><div></div><div></div><div></div><div></div><div></div><div></div><div></div></div></div>;
+    const divLoader = (
+        <div className="lds-roller-container">
+            <div className="lds-roller">
+                <div></div>
+                <div></div>
+                <div></div>
+                <div></div>
+                <div></div>
+                <div></div>
+                <div></div>
+                <div></div>
+            </div>
+        </div>
+    );
     return (
         <div className={`ref ${displayMap ? "view-map" : "no-map"}`}>
             <div
                 className="r-result-filter-container"
                 ref={filterRef}
-                style={{ top: portalHeaderHeight }}
+                style={{ top: headerHeight }}
             >
                 <div
                     id="r-result-filter"
@@ -148,77 +166,94 @@ function AnnuaireView(props) {
                         activeFilter={filters}
                         onChange={filtersChange}
                     />
-                    {props.proposeUrl &&
-                        (
-                            <div className="r-add-contact">
-                                <a target="_blank" rel="noreferrer" href={props.proposeUrl}><Translate text='Proposer un contact' /></a>
-                            </div>
-                        )
-                    }
+                    {props.proposeUrl && (
+                        <div className="r-add-contact">
+                            <a target="_blank" rel="noreferrer" href={props.proposeUrl}>
+                                <Translate text="Proposer un contact" />
+                            </a>
+                        </div>
+                    )}
                     {contactNumber > 0 ? (
                         <p className="r-results-numbers">
                             <span>{contactNumber}</span>
-                            {contactNumber > 1
-                                ? <Translate text='contacts trouvés' />
-                                : <Translate text='contact trouvé' />}
+                            {contactNumber > 1 ? (
+                                <Translate text="contacts trouvés" />
+                            ) : (
+                                <Translate text="contact trouvé" />
+                            )}
                         </p>
                     ) : (
-                        <p className="r-results-numbers"><Translate text='Aucun résultat' /></p>
+                        <p className="r-results-numbers">
+                            <Translate text="Aucun résultat" />
+                        </p>
                     )}
                 </div>
             </div>
-            <Switch>
-                <Route exact path="/">
-                    <div className="r-wrapper container r-annuaire-wrapper">
-                        <div className="r-result r-annuaire-result">
-                            <div>{listRender}</div>
-                            <div className="r-load-more">
-                                {contactNumber - props.batchSize > batchStart ? (
-                                    <div>
+            <Routes>
+                <Route
+                    exact
+                    path="/"
+                    element={
+                        <div className="r-wrapper container r-annuaire-wrapper">
+                            <div className="r-result r-annuaire-result">
+                                <div>{listRender}</div>
+                                <div className="r-load-more">
+                                    {contactNumber - props.batchSize > batchStart ? (
+                                        <div>
+                                            <span className="no-more-result">
+                                                {isLoading ? divLoader : ""}
+                                            </span>
+                                            <button onClick={loadMore} className="btn-grad">
+                                                {isLoading ? (
+                                                    <Translate text="Chargement..." />
+                                                ) : (
+                                                    <Translate text="Plus de résultats" />
+                                                )}
+                                            </button>
+                                        </div>
+                                    ) : (
                                         <span className="no-more-result">
                                             {isLoading ? divLoader : ""}
                                         </span>
-                                        <button onClick={loadMore} className="btn-grad">
-                                            {isLoading ? <Translate text='Chargement...' /> : <Translate text='Plus de résultats' />}
-                                        </button>
-                                    </div>
-                                ) : (
-                                    <span className="no-more-result">
-                                        {isLoading ? divLoader : ""}
-                                    </span>
-                                )}
+                                    )}
+                                </div>
                             </div>
+                            {displayMap && (
+                                <div
+                                    className="r-map annuaire-map"
+                                    style={{
+                                        top: style.height + headerHeight,
+                                        height: "calc(100vh-" + style.height + headerHeight,
+                                    }}
+                                >
+                                    {MapRender}
+                                </div>
+                            )}
                         </div>
-                        {displayMap && <div
-                            className="r-map annuaire-map"
-                            style={{
-                                top: style.height + portalHeaderHeight,
-                                height: "calc(100vh-" + style.height + portalHeaderHeight,
-                            }}
-                        >
-                            {MapRender}
+                    }
+                ></Route>
+                <Route
+                    path={"/:name"}
+                    element={
+                        <div className="r-wrapper container r-annuaire-wrapper">
+                            <div className="r-result r-annuaire-result">
+                                <ContactContent queryUrl={props.queryUrl} onChange={clickID} />
+                            </div>
+                            {displayMap && (
+                                <div
+                                    className="r-map annuaire-map"
+                                    style={{
+                                        top: style.height + headerHeight,
+                                        height: "calc(100vh-" + style.height + headerHeight,
+                                    }}
+                                >
+                                    {MapRender}
+                                </div>
+                            )}
                         </div>
-                        }
-                    </div>
-                </Route>
-                <Route path={"/:name"}>
-                    <div className="r-wrapper container r-annuaire-wrapper">
-                        <div className="r-result r-annuaire-result">
-                            <ContactContent queryUrl={props.queryUrl} onChange={clickID} />
-                        </div>
-                        {displayMap && <div
-                            className="r-map annuaire-map"
-                            style={{
-                                top: style.height + portalHeaderHeight,
-                                height: "calc(100vh-" + style.height + portalHeaderHeight,
-                            }}
-                        >
-                            {MapRender}
-                        </div>
-                        }
-                    </div>
-                </Route>
-            </Switch>
+                    }
+                ></Route>
+            </Routes>
         </div>
     );
 }
