@@ -1,5 +1,4 @@
-import React from "react";
-import { BrowserRouter as Router, Link, useLocation } from "react-router-dom";
+import { useLocation } from "react-router-dom";
 
 function useFilterQuery() {
     return new URLSearchParams(useLocation().search);
